============
``salt-api``
============

Start interfaces used to remotely connect to the salt master

Synopsis
========

.. code-block:: bash

    salt-api 

Description
===========

The Salt API system manages network api connectors for the Salt Master

Options
=======

.. program:: salt-api

.. option:: -h, --help

    Print a usage message briefly summarizing these command-line options.

.. option:: -C CONFIG, --config=CONFIG

    Specify an alternative location for the salt master configuration file.

See also
========

:manpage:`salt-api(7)`
:manpage:`salt(7)`
:manpage:`salt-master(1)`
